Comments

realityloop created an issue. See original summary.

realityloop’s picture

Not taking credit for this, posting here from a github gist.

realityloop’s picture

gro’s picture

StatusFileSize
new1018 bytes

Updates variable assignment of drupal_static to use pass by reference.

realityloop’s picture

StatusFileSize
new746 bytes

This patch is just to mitigate some of these performance issues (you probably don't want to use it yourself).

chop’s picture

Status: Active » Needs review
StatusFileSize
new1.03 KB

Motivation for this patch is solid. Re-rolling against the latest 8.x-1.x branch to work with latest rc2.

It may be that some of the performance issues are mitigated by Node Grants changes for anonymous visitors.

chop’s picture

Hiding this patch to bypass View Access checks now that Group Node has addressed performance issues with anonymous visitors and access checks.

See commit 11ef18a09c7d2c220a10a485802ffec155068a7e

visabhishek’s picture

StatusFileSize
new114.76 KB
new112.97 KB
new119.25 KB
new115.7 KB
new5.75 KB

Still, I am facing the performance issue based on the number of group membership, I want to share some statistic based on my test.

  1. Module Used Group:8.x-1.x-dev
  2. I have created 3 Type of group with relevant permission, which was Open, Moderate and Private.
  3. I have a total of 40 groups with a combination of Open, Moderate and Private group type.
  4. User1 has the membership for all 40 groups
  5. User2 has the membership for 6 group only


Now I am trying to access the same group content list page (group/1/content/) from both users with apache benchmark and result are as follow

User1
User1 Data

User2
User2 Data

I am trying to cache "gnode_node_grants" permission strings based on user and result is very exciting.

User1
Patched user1

User2
Patched user2

I am attaching initial patch where I am trying to cache the permissions to check " is I am on right path ?". ( Right now I am not invalidating the cache we can discuss latter for this)

Status: Needs review » Needs work

The last submitted patch, 8: cached_permission.patch, failed testing. View results
- codesniffer_fixes.patch Interdiff of automated coding standards fixes only.

idebr’s picture

Closed #3024031: Performance of gnode_node_grants as a duplicate issue.

jayelless’s picture

What is the current status of this issue? Now that RC3 with the re-factored caching is out, should this issue be closed ad "fixed"?

jayelless’s picture

Status: Needs work » Closed (duplicate)
Related issues: +#3029849: Statically cache gnode_node_grants()